@@ -113,8 +113,6 @@ def getTotalSize(path, finishFiles):
     targetFiles = getAllFiles(path)
     totalSize = 0
     for item in targetFiles:
-        if item in finishFiles:
-            continue
         with open(path+item, 'a') as f:
             fileSize = getFileSize(f)
             totalChunks = int(fileSize / chunkSize)
@@ -172,14 +170,18 @@ def uploadPathFiles(id,type,uuid, path):
     while finish == False:
         error = False
         for item in targetFiles:
-            if item in finishFiles.keys():
-                continue
             with open(path+item, 'a') as f:
                 fileSize = getFileSize(f)
                 totalChunks = int(fileSize / chunkSize)
                 lastSize = fileSize % chunkSize
                 if lastSize != 0:
                    totalChunks = totalChunks + 1
+                if totalChunks == 0:
+                    totalChunks = totalChunks + 1
+                if item in finishFiles.keys():
+                    finishSize = finishSize + totalChunks
+                    process_bar.show_process(finishSize)
+                    continue
                 if totalChunks == 1 or totalChunks == 0 :
                     result = fileChunckUpLoad(path, apiUrl, item, 1, 1, fileSize)
                     if result == True:
